@@ -11,8 +11,13 @@
 
 /*LINTLIBRARY*/
 
-#ifndef	_XOPEN_SOURCE
-#   define _XOPEN_SOURCE 500
+#include "config.h"
+
+#include "converter.h"		/* this module's API */
+
+#ifdef _MSC_VER
+#define _USE_MATH_DEFINES
+#include "udunits2.h" /* For the MSVC-specific defines. */
 #endif
 
 #include <math.h>
@@ -21,8 +26,6 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "converter.h"		/* this module's API */
-
 typedef struct {
     cv_converter*	(*clone)(cv_converter*);
     double		(*convertDouble)
@@ -478,9 +481,9 @@ offsetGetExpression(
 
     return
 	cvNeedsParentheses(variable)
-	    ? snprintf(buf, max, "(%s) %c %g", variable, oper, 
+	    ? snprintf(buf, max, "(%s) %c %g", variable, oper,
 		fabs(conv->offset.value))
-	    : snprintf(buf, max, "%s %c %g", variable, oper, 
+	    : snprintf(buf, max, "%s %c %g", variable, oper,
 		fabs(conv->offset.value));
 }
 
@@ -559,12 +562,12 @@ galileanConvertDoubles(
 
 	if (in < out) {
 	    for (i = count; i-- > 0;)
-		out[i] = conv->galilean.slope * in[i] + 
+		out[i] = conv->galilean.slope * in[i] +
 		    conv->galilean.intercept;
 	}
 	else {
 	    for (i = 0; i < count; i++)
-		out[i] = conv->galilean.slope * in[i] + 
+		out[i] = conv->galilean.slope * in[i] +
 		    conv->galilean.intercept;
 	}
     }
@@ -690,7 +693,7 @@ logGetExpression(
     const size_t		max,
     const char* const		variable)
 {
-    return 
+    return
         conv->log.logE == M_LOG2E
             ? snprintf(buf, max, "lb(%s)", variable)
             : conv->log.logE == 1
@@ -791,7 +794,7 @@ expGetExpression(
     const size_t		max,
     const char* const		variable)
 {
-    return 
+    return
 	cvNeedsParentheses(variable)
 	    ? snprintf(buf, max, "pow(%g, (%s))", conv->exp.base, variable)
 	    : snprintf(buf, max, "pow(%g, %s)", conv->exp.base, variable);
@@ -864,7 +867,7 @@ compositeConvertDoubles(
 	out = NULL;
     }
     else {
-	out = 
+	out =
 	    cv_convert_doubles(
 		conv->composite.second,
 		cv_convert_doubles(conv->composite.first, in, count, out),
@@ -901,7 +904,7 @@ compositeGetExpression(
 	buf[max-1] = 0;
 
 	if (cvNeedsParentheses(buf)) {
-	    nchar = snprintf(tmpBuf, sizeof(tmpBuf), "(%s)", buf);
+	    (void)snprintf(tmpBuf, sizeof(tmpBuf), "(%s)", buf);
 	}
 	else {
 	    (void)strncpy(tmpBuf, buf, sizeof(tmpBuf));
@@ -1051,13 +1054,12 @@ cv_get_galilean(
 	conv = cv_get_scale(slope);
     }
     else {
-	cv_converter*	tmp = malloc(sizeof(GalileanConverter));
+	conv = malloc(sizeof(GalileanConverter));
 
-	if (tmp != NULL) {
-	    tmp->ops = &galileanOps;
-	    tmp->galilean.slope = slope;
-	    tmp->galilean.intercept = intercept;
-	    conv = tmp;
+	if (conv != NULL) {
+	    conv->ops = &galileanOps;
+	    conv->galilean.slope = slope;
+	    conv->galilean.intercept = intercept;
 	}
     }
 
@@ -1092,7 +1094,7 @@ cv_get_log(
 
 	if (conv != NULL) {
 	    conv->ops = &logOps;
-	    conv->log.logE = 
+	    conv->log.logE =
                 base == 2
                     ? M_LOG2E
                     : base == M_E
@@ -1192,20 +1194,20 @@ cv_combine(
 	    }
 	    else if (IS_GALILEAN(second)) {
 		conv = cv_get_galilean(
-		    first->scale.value * second->galilean.slope, 
+		    first->scale.value * second->galilean.slope,
 		    second->galilean.intercept);
 	    }
 	}
 	else if (IS_OFFSET(first)) {
 	    if (IS_SCALE(second)) {
-		conv = cv_get_galilean(second->scale.value, 
+		conv = cv_get_galilean(second->scale.value,
 		    first->offset.value * second->scale.value);
 	    }
 	    else if (IS_OFFSET(second)) {
 		conv = cv_get_offset(first->offset.value + second->offset.value);
 	    }
 	    else if (IS_GALILEAN(second)) {
-		conv = cv_get_galilean(second->galilean.slope, 
+		conv = cv_get_galilean(second->galilean.slope,
 		    first->offset.value * second->galilean.slope +
 			second->galilean.intercept);
 	    }
